@@ -10,9 +10,13 @@ import glob
 import os
 import shutil
 import requests
+import platform
+import tempfile
+from pathlib import Path
 
 current_path = os.getcwd()
 BASE_URL = 'http://49.12.101.190'
+user_home = str(Path.home())
 
 def recursive_copy_files(source_path, destination_path, override=False):
     """
@@ -193,6 +197,7 @@ class ParsPaas(object):
 
     @staticmethod
     def login():
+        hard_logout()
         result = ''
         if check_internet_work() is not True:
             print("you are not connected to the internet yet")
@@ -216,6 +221,10 @@ class ParsPaas(object):
         username = credentials['username']
         password = credentials['password']
         data = {'username': username, 'password': password}
+        os_system = platform.system()
+        os_release = platform.release()
+        os_version = platform.version()
+        # print(tempfile.gettempdir())
         r = requests.post(BASE_URL + '/api/auth/login/', data=data)
         x = r.json()
         if r.status_code == 200:
@@ -223,7 +232,7 @@ class ParsPaas(object):
             try:
                 if x['access'] is not None:
                     init()
-                    with open(current_path + '/.cloud/a4e1daa4f02f756b865ce2f9a9f9b689', 'w') as commit:
+                    with open(user_home + '/.cloud/a4e1daa4f02f756b865ce2f9a9f9b689', 'w') as commit:
                         commit.write(x['access'])
                     result = "successfully logged in ..."
                 else:
@@ -259,7 +268,7 @@ class ParsPaas(object):
         if answer:
 
             try:
-                myf = current_path + '/.cloud/a4e1daa4f02f756b865ce2f9a9f9b689'
+                myf = user_home + '/.cloud/a4e1daa4f02f756b865ce2f9a9f9b689'
                 os.remove(myf)
                 result = "successfully logged out"
             except:
@@ -272,6 +281,15 @@ class ParsPaas(object):
 
         return "result"
 
+def hard_logout():
+    try:
+        myf = user_home + '/.cloud/a4e1daa4f02f756b865ce2f9a9f9b689'
+        os.remove(myf)
+        result = " "
+    except TypeError as te:
+        result = ""
+
+    return result
 
 def run():
     fire.Fire(ParsPaas)
